sglearn package
===============

Submodules
----------

sglearn.featurization module
----------------------------

.. automodule:: sglearn.featurization
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: sglearn
   :members:
   :undoc-members:
   :show-inheritance:
